# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['TopicArgs', 'Topic']

@pulumi.input_type
class TopicArgs:
    def __init__(__self__, *,
                 instance_id: pulumi.Input[builtins.str],
                 partition_number: pulumi.Input[builtins.int],
                 topic_name: pulumi.Input[builtins.str],
                 access_policies: Optional[pulumi.Input[Sequence[pulumi.Input['TopicAccessPolicyArgs']]]] = None,
                 all_authority: Optional[pulumi.Input[builtins.bool]] = None,
                 cleanup_policies: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 parameters: Optional[pulumi.Input[builtins.str]] = None,
                 replica_number: Optional[pulumi.Input[builtins.int]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['TopicTagArgs']]]] = None):
        """
        The set of arguments for constructing a Topic resource.
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        :param pulumi.Input[builtins.int] partition_number: Topic 分区数。取值范围为 1~300，如果实例中已创建了其他 Topic，则所有 Topic 的分区数之和不超过该实例的分区数上限。如果分区数无法满足业务需求，您可以购买更多分区，提升实例的分区数量上限。
        :param pulumi.Input[builtins.str] topic_name: 待创建的 Topic 名称。3～64 个字符。必须以英文或数字开头。支持的字符包括英文、数字、连字符（-）、下划线（_）和英文句号（.）。
        :param pulumi.Input[builtins.bool] all_authority: 待创建的Topic默认是否对所有用户都开启读写权限。true：（默认）所有用户都具备此 Topic 的读写权限。false：并非所有用户都具备此 Topic 的读写权限。默认情况下，用户对于此 Topic 的权限沿用用户的默认权限，如果默认权限不满足需求，您也可以通过 AccessPolicies 指定某个用户对于此 Topic 的自定义权限。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] cleanup_policies: Topic 的消息清理策略，支持以下三种取值方式：[delete]：默认的消息清理策略。在磁盘容量充足的情况下，保留在最长保留时间范围内的消息；在磁盘容量不足时，将提前删除旧消息，以保证服务可用性。[compact]：COMPACT 消息清理策略针对每个消息的 Key 进行整合，对于有相同 Key 的消息，只保留最新的 value 值，旧的记录则会被清除。[delete,compact]：同时配置 DELETE 和 COMPACT 两种消息清理策略。只要消息满足任一条清理策略时，都将被清除。
        :param pulumi.Input[builtins.str] description: Topic 的描述信息。长度不超过 128 个字符。
        :param pulumi.Input[builtins.str] parameters: Topic 级别的参数配置。Parameters 参数说明 MinInsyncReplicaNumber:2：最小同步副本个数。当同步副本个数小于配置值时，消息将无法写入对应 Topic。配置值越大，数据可靠性增加，但是可用性将会降低。默认值为副本数减 1。考虑到 Topic 的可用性，建议设置为副本数减 1。MessageMaxByte:12：最大消息大小。单位为 MB，取值范围为 1～12。默认沿用实例的最大消息大小设置。LogRetentionHours:72：消息保留时长。单位为小时，取值范围为 0～2160，即消息最久保留 90 天。默认沿用实例的消息保留时长设置。
        :param pulumi.Input[builtins.int] replica_number: Topic 副本个数。可设置为为 2 或 3，默认值为 3。
        """
        pulumi.set(__self__, "instance_id", instance_id)
        pulumi.set(__self__, "partition_number", partition_number)
        pulumi.set(__self__, "topic_name", topic_name)
        if access_policies is not None:
            pulumi.set(__self__, "access_policies", access_policies)
        if all_authority is not None:
            pulumi.set(__self__, "all_authority", all_authority)
        if cleanup_policies is not None:
            pulumi.set(__self__, "cleanup_policies", cleanup_policies)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if parameters is not None:
            pulumi.set(__self__, "parameters", parameters)
        if replica_number is not None:
            pulumi.set(__self__, "replica_number", replica_number)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Input[builtins.str]:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="partitionNumber")
    def partition_number(self) -> pulumi.Input[builtins.int]:
        """
        Topic 分区数。取值范围为 1~300，如果实例中已创建了其他 Topic，则所有 Topic 的分区数之和不超过该实例的分区数上限。如果分区数无法满足业务需求，您可以购买更多分区，提升实例的分区数量上限。
        """
        return pulumi.get(self, "partition_number")

    @partition_number.setter
    def partition_number(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "partition_number", value)

    @property
    @pulumi.getter(name="topicName")
    def topic_name(self) -> pulumi.Input[builtins.str]:
        """
        待创建的 Topic 名称。3～64 个字符。必须以英文或数字开头。支持的字符包括英文、数字、连字符（-）、下划线（_）和英文句号（.）。
        """
        return pulumi.get(self, "topic_name")

    @topic_name.setter
    def topic_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "topic_name", value)

    @property
    @pulumi.getter(name="accessPolicies")
    def access_policies(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['TopicAccessPolicyArgs']]]]:
        return pulumi.get(self, "access_policies")

    @access_policies.setter
    def access_policies(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['TopicAccessPolicyArgs']]]]):
        pulumi.set(self, "access_policies", value)

    @property
    @pulumi.getter(name="allAuthority")
    def all_authority(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        待创建的Topic默认是否对所有用户都开启读写权限。true：（默认）所有用户都具备此 Topic 的读写权限。false：并非所有用户都具备此 Topic 的读写权限。默认情况下，用户对于此 Topic 的权限沿用用户的默认权限，如果默认权限不满足需求，您也可以通过 AccessPolicies 指定某个用户对于此 Topic 的自定义权限。
        """
        return pulumi.get(self, "all_authority")

    @all_authority.setter
    def all_authority(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "all_authority", value)

    @property
    @pulumi.getter(name="cleanupPolicies")
    def cleanup_policies(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        Topic 的消息清理策略，支持以下三种取值方式：[delete]：默认的消息清理策略。在磁盘容量充足的情况下，保留在最长保留时间范围内的消息；在磁盘容量不足时，将提前删除旧消息，以保证服务可用性。[compact]：COMPACT 消息清理策略针对每个消息的 Key 进行整合，对于有相同 Key 的消息，只保留最新的 value 值，旧的记录则会被清除。[delete,compact]：同时配置 DELETE 和 COMPACT 两种消息清理策略。只要消息满足任一条清理策略时，都将被清除。
        """
        return pulumi.get(self, "cleanup_policies")

    @cleanup_policies.setter
    def cleanup_policies(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "cleanup_policies", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Topic 的描述信息。长度不超过 128 个字符。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def parameters(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Topic 级别的参数配置。Parameters 参数说明 MinInsyncReplicaNumber:2：最小同步副本个数。当同步副本个数小于配置值时，消息将无法写入对应 Topic。配置值越大，数据可靠性增加，但是可用性将会降低。默认值为副本数减 1。考虑到 Topic 的可用性，建议设置为副本数减 1。MessageMaxByte:12：最大消息大小。单位为 MB，取值范围为 1～12。默认沿用实例的最大消息大小设置。LogRetentionHours:72：消息保留时长。单位为小时，取值范围为 0～2160，即消息最久保留 90 天。默认沿用实例的消息保留时长设置。
        """
        return pulumi.get(self, "parameters")

    @parameters.setter
    def parameters(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "parameters", value)

    @property
    @pulumi.getter(name="replicaNumber")
    def replica_number(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Topic 副本个数。可设置为为 2 或 3，默认值为 3。
        """
        return pulumi.get(self, "replica_number")

    @replica_number.setter
    def replica_number(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "replica_number", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['TopicTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['TopicTagArgs']]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _TopicState:
    def __init__(__self__, *,
                 access_policies: Optional[pulumi.Input[Sequence[pulumi.Input['TopicAccessPolicyArgs']]]] = None,
                 all_authority: Optional[pulumi.Input[builtins.bool]] = None,
                 cleanup_policies: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 log_retention_hours: Optional[pulumi.Input[builtins.int]] = None,
                 parameters: Optional[pulumi.Input[builtins.str]] = None,
                 partition_number: Optional[pulumi.Input[builtins.int]] = None,
                 replica_number: Optional[pulumi.Input[builtins.int]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['TopicTagArgs']]]] = None,
                 topic_name: Optional[pulumi.Input[builtins.str]] = None,
                 used_storage_percentage_in_instance: Optional[pulumi.Input[builtins.float]] = None,
                 used_storage_space_in_bytes: Optional[pulumi.Input[builtins.int]] = None):
        """
        Input properties used for looking up and filtering Topic resources.
        :param pulumi.Input[builtins.bool] all_authority: 待创建的Topic默认是否对所有用户都开启读写权限。true：（默认）所有用户都具备此 Topic 的读写权限。false：并非所有用户都具备此 Topic 的读写权限。默认情况下，用户对于此 Topic 的权限沿用用户的默认权限，如果默认权限不满足需求，您也可以通过 AccessPolicies 指定某个用户对于此 Topic 的自定义权限。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] cleanup_policies: Topic 的消息清理策略，支持以下三种取值方式：[delete]：默认的消息清理策略。在磁盘容量充足的情况下，保留在最长保留时间范围内的消息；在磁盘容量不足时，将提前删除旧消息，以保证服务可用性。[compact]：COMPACT 消息清理策略针对每个消息的 Key 进行整合，对于有相同 Key 的消息，只保留最新的 value 值，旧的记录则会被清除。[delete,compact]：同时配置 DELETE 和 COMPACT 两种消息清理策略。只要消息满足任一条清理策略时，都将被清除。
        :param pulumi.Input[builtins.str] created_time: Topic 的创建时间。
        :param pulumi.Input[builtins.str] description: Topic 的描述信息。长度不超过 128 个字符。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        :param pulumi.Input[builtins.int] log_retention_hours: 消息保留时长，单位小时。Topic维度的消息保留时长，取值范围：1   - 2160小时（90天）。
        :param pulumi.Input[builtins.str] parameters: Topic 级别的参数配置。Parameters 参数说明 MinInsyncReplicaNumber:2：最小同步副本个数。当同步副本个数小于配置值时，消息将无法写入对应 Topic。配置值越大，数据可靠性增加，但是可用性将会降低。默认值为副本数减 1。考虑到 Topic 的可用性，建议设置为副本数减 1。MessageMaxByte:12：最大消息大小。单位为 MB，取值范围为 1～12。默认沿用实例的最大消息大小设置。LogRetentionHours:72：消息保留时长。单位为小时，取值范围为 0～2160，即消息最久保留 90 天。默认沿用实例的消息保留时长设置。
        :param pulumi.Input[builtins.int] partition_number: Topic 分区数。取值范围为 1~300，如果实例中已创建了其他 Topic，则所有 Topic 的分区数之和不超过该实例的分区数上限。如果分区数无法满足业务需求，您可以购买更多分区，提升实例的分区数量上限。
        :param pulumi.Input[builtins.int] replica_number: Topic 副本个数。可设置为为 2 或 3，默认值为 3。
        :param pulumi.Input[builtins.str] status: Topic 的状态。
        :param pulumi.Input[builtins.str] topic_name: 待创建的 Topic 名称。3～64 个字符。必须以英文或数字开头。支持的字符包括英文、数字、连字符（-）、下划线（_）和英文句号（.）。
        :param pulumi.Input[builtins.float] used_storage_percentage_in_instance: 当前 Topic 总数据量占实例总存储空间的比例，控制台页面显示为保留两位小数的百分数。
        :param pulumi.Input[builtins.int] used_storage_space_in_bytes: 当前 Topic 已使用的总存储空间大小。
        """
        if access_policies is not None:
            pulumi.set(__self__, "access_policies", access_policies)
        if all_authority is not None:
            pulumi.set(__self__, "all_authority", all_authority)
        if cleanup_policies is not None:
            pulumi.set(__self__, "cleanup_policies", cleanup_policies)
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if log_retention_hours is not None:
            pulumi.set(__self__, "log_retention_hours", log_retention_hours)
        if parameters is not None:
            pulumi.set(__self__, "parameters", parameters)
        if partition_number is not None:
            pulumi.set(__self__, "partition_number", partition_number)
        if replica_number is not None:
            pulumi.set(__self__, "replica_number", replica_number)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if topic_name is not None:
            pulumi.set(__self__, "topic_name", topic_name)
        if used_storage_percentage_in_instance is not None:
            pulumi.set(__self__, "used_storage_percentage_in_instance", used_storage_percentage_in_instance)
        if used_storage_space_in_bytes is not None:
            pulumi.set(__self__, "used_storage_space_in_bytes", used_storage_space_in_bytes)

    @property
    @pulumi.getter(name="accessPolicies")
    def access_policies(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['TopicAccessPolicyArgs']]]]:
        return pulumi.get(self, "access_policies")

    @access_policies.setter
    def access_policies(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['TopicAccessPolicyArgs']]]]):
        pulumi.set(self, "access_policies", value)

    @property
    @pulumi.getter(name="allAuthority")
    def all_authority(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        待创建的Topic默认是否对所有用户都开启读写权限。true：（默认）所有用户都具备此 Topic 的读写权限。false：并非所有用户都具备此 Topic 的读写权限。默认情况下，用户对于此 Topic 的权限沿用用户的默认权限，如果默认权限不满足需求，您也可以通过 AccessPolicies 指定某个用户对于此 Topic 的自定义权限。
        """
        return pulumi.get(self, "all_authority")

    @all_authority.setter
    def all_authority(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "all_authority", value)

    @property
    @pulumi.getter(name="cleanupPolicies")
    def cleanup_policies(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        Topic 的消息清理策略，支持以下三种取值方式：[delete]：默认的消息清理策略。在磁盘容量充足的情况下，保留在最长保留时间范围内的消息；在磁盘容量不足时，将提前删除旧消息，以保证服务可用性。[compact]：COMPACT 消息清理策略针对每个消息的 Key 进行整合，对于有相同 Key 的消息，只保留最新的 value 值，旧的记录则会被清除。[delete,compact]：同时配置 DELETE 和 COMPACT 两种消息清理策略。只要消息满足任一条清理策略时，都将被清除。
        """
        return pulumi.get(self, "cleanup_policies")

    @cleanup_policies.setter
    def cleanup_policies(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "cleanup_policies", value)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Topic 的创建时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Topic 的描述信息。长度不超过 128 个字符。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="logRetentionHours")
    def log_retention_hours(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        消息保留时长，单位小时。Topic维度的消息保留时长，取值范围：1   - 2160小时（90天）。
        """
        return pulumi.get(self, "log_retention_hours")

    @log_retention_hours.setter
    def log_retention_hours(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "log_retention_hours", value)

    @property
    @pulumi.getter
    def parameters(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Topic 级别的参数配置。Parameters 参数说明 MinInsyncReplicaNumber:2：最小同步副本个数。当同步副本个数小于配置值时，消息将无法写入对应 Topic。配置值越大，数据可靠性增加，但是可用性将会降低。默认值为副本数减 1。考虑到 Topic 的可用性，建议设置为副本数减 1。MessageMaxByte:12：最大消息大小。单位为 MB，取值范围为 1～12。默认沿用实例的最大消息大小设置。LogRetentionHours:72：消息保留时长。单位为小时，取值范围为 0～2160，即消息最久保留 90 天。默认沿用实例的消息保留时长设置。
        """
        return pulumi.get(self, "parameters")

    @parameters.setter
    def parameters(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "parameters", value)

    @property
    @pulumi.getter(name="partitionNumber")
    def partition_number(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Topic 分区数。取值范围为 1~300，如果实例中已创建了其他 Topic，则所有 Topic 的分区数之和不超过该实例的分区数上限。如果分区数无法满足业务需求，您可以购买更多分区，提升实例的分区数量上限。
        """
        return pulumi.get(self, "partition_number")

    @partition_number.setter
    def partition_number(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "partition_number", value)

    @property
    @pulumi.getter(name="replicaNumber")
    def replica_number(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Topic 副本个数。可设置为为 2 或 3，默认值为 3。
        """
        return pulumi.get(self, "replica_number")

    @replica_number.setter
    def replica_number(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "replica_number", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Topic 的状态。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['TopicTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['TopicTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="topicName")
    def topic_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        待创建的 Topic 名称。3～64 个字符。必须以英文或数字开头。支持的字符包括英文、数字、连字符（-）、下划线（_）和英文句号（.）。
        """
        return pulumi.get(self, "topic_name")

    @topic_name.setter
    def topic_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "topic_name", value)

    @property
    @pulumi.getter(name="usedStoragePercentageInInstance")
    def used_storage_percentage_in_instance(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        当前 Topic 总数据量占实例总存储空间的比例，控制台页面显示为保留两位小数的百分数。
        """
        return pulumi.get(self, "used_storage_percentage_in_instance")

    @used_storage_percentage_in_instance.setter
    def used_storage_percentage_in_instance(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "used_storage_percentage_in_instance", value)

    @property
    @pulumi.getter(name="usedStorageSpaceInBytes")
    def used_storage_space_in_bytes(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        当前 Topic 已使用的总存储空间大小。
        """
        return pulumi.get(self, "used_storage_space_in_bytes")

    @used_storage_space_in_bytes.setter
    def used_storage_space_in_bytes(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "used_storage_space_in_bytes", value)


@pulumi.type_token("bytepluscc:kafka/topic:Topic")
class Topic(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_policies: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TopicAccessPolicyArgs', 'TopicAccessPolicyArgsDict']]]]] = None,
                 all_authority: Optional[pulumi.Input[builtins.bool]] = None,
                 cleanup_policies: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 parameters: Optional[pulumi.Input[builtins.str]] = None,
                 partition_number: Optional[pulumi.Input[builtins.int]] = None,
                 replica_number: Optional[pulumi.Input[builtins.int]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TopicTagArgs', 'TopicTagArgsDict']]]]] = None,
                 topic_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Topic即消息的主题，用于分类消息。支持 Topic 级别的资源管理，即 Topic 的创建、查看与删除等操作。

        ## Import

        ```sh
        $ pulumi import bytepluscc:kafka/topic:Topic example "instance_id|topic_name"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] all_authority: 待创建的Topic默认是否对所有用户都开启读写权限。true：（默认）所有用户都具备此 Topic 的读写权限。false：并非所有用户都具备此 Topic 的读写权限。默认情况下，用户对于此 Topic 的权限沿用用户的默认权限，如果默认权限不满足需求，您也可以通过 AccessPolicies 指定某个用户对于此 Topic 的自定义权限。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] cleanup_policies: Topic 的消息清理策略，支持以下三种取值方式：[delete]：默认的消息清理策略。在磁盘容量充足的情况下，保留在最长保留时间范围内的消息；在磁盘容量不足时，将提前删除旧消息，以保证服务可用性。[compact]：COMPACT 消息清理策略针对每个消息的 Key 进行整合，对于有相同 Key 的消息，只保留最新的 value 值，旧的记录则会被清除。[delete,compact]：同时配置 DELETE 和 COMPACT 两种消息清理策略。只要消息满足任一条清理策略时，都将被清除。
        :param pulumi.Input[builtins.str] description: Topic 的描述信息。长度不超过 128 个字符。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        :param pulumi.Input[builtins.str] parameters: Topic 级别的参数配置。Parameters 参数说明 MinInsyncReplicaNumber:2：最小同步副本个数。当同步副本个数小于配置值时，消息将无法写入对应 Topic。配置值越大，数据可靠性增加，但是可用性将会降低。默认值为副本数减 1。考虑到 Topic 的可用性，建议设置为副本数减 1。MessageMaxByte:12：最大消息大小。单位为 MB，取值范围为 1～12。默认沿用实例的最大消息大小设置。LogRetentionHours:72：消息保留时长。单位为小时，取值范围为 0～2160，即消息最久保留 90 天。默认沿用实例的消息保留时长设置。
        :param pulumi.Input[builtins.int] partition_number: Topic 分区数。取值范围为 1~300，如果实例中已创建了其他 Topic，则所有 Topic 的分区数之和不超过该实例的分区数上限。如果分区数无法满足业务需求，您可以购买更多分区，提升实例的分区数量上限。
        :param pulumi.Input[builtins.int] replica_number: Topic 副本个数。可设置为为 2 或 3，默认值为 3。
        :param pulumi.Input[builtins.str] topic_name: 待创建的 Topic 名称。3～64 个字符。必须以英文或数字开头。支持的字符包括英文、数字、连字符（-）、下划线（_）和英文句号（.）。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: TopicArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Topic即消息的主题，用于分类消息。支持 Topic 级别的资源管理，即 Topic 的创建、查看与删除等操作。

        ## Import

        ```sh
        $ pulumi import bytepluscc:kafka/topic:Topic example "instance_id|topic_name"
        ```

        :param str resource_name: The name of the resource.
        :param TopicArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(TopicArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_policies: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TopicAccessPolicyArgs', 'TopicAccessPolicyArgsDict']]]]] = None,
                 all_authority: Optional[pulumi.Input[builtins.bool]] = None,
                 cleanup_policies: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 parameters: Optional[pulumi.Input[builtins.str]] = None,
                 partition_number: Optional[pulumi.Input[builtins.int]] = None,
                 replica_number: Optional[pulumi.Input[builtins.int]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TopicTagArgs', 'TopicTagArgsDict']]]]] = None,
                 topic_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = TopicArgs.__new__(TopicArgs)

            __props__.__dict__["access_policies"] = access_policies
            __props__.__dict__["all_authority"] = all_authority
            __props__.__dict__["cleanup_policies"] = cleanup_policies
            __props__.__dict__["description"] = description
            if instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'instance_id'")
            __props__.__dict__["instance_id"] = instance_id
            __props__.__dict__["parameters"] = parameters
            if partition_number is None and not opts.urn:
                raise TypeError("Missing required property 'partition_number'")
            __props__.__dict__["partition_number"] = partition_number
            __props__.__dict__["replica_number"] = replica_number
            __props__.__dict__["tags"] = tags
            if topic_name is None and not opts.urn:
                raise TypeError("Missing required property 'topic_name'")
            __props__.__dict__["topic_name"] = topic_name
            __props__.__dict__["created_time"] = None
            __props__.__dict__["log_retention_hours"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["used_storage_percentage_in_instance"] = None
            __props__.__dict__["used_storage_space_in_bytes"] = None
        super(Topic, __self__).__init__(
            'bytepluscc:kafka/topic:Topic',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            access_policies: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TopicAccessPolicyArgs', 'TopicAccessPolicyArgsDict']]]]] = None,
            all_authority: Optional[pulumi.Input[builtins.bool]] = None,
            cleanup_policies: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            instance_id: Optional[pulumi.Input[builtins.str]] = None,
            log_retention_hours: Optional[pulumi.Input[builtins.int]] = None,
            parameters: Optional[pulumi.Input[builtins.str]] = None,
            partition_number: Optional[pulumi.Input[builtins.int]] = None,
            replica_number: Optional[pulumi.Input[builtins.int]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TopicTagArgs', 'TopicTagArgsDict']]]]] = None,
            topic_name: Optional[pulumi.Input[builtins.str]] = None,
            used_storage_percentage_in_instance: Optional[pulumi.Input[builtins.float]] = None,
            used_storage_space_in_bytes: Optional[pulumi.Input[builtins.int]] = None) -> 'Topic':
        """
        Get an existing Topic resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] all_authority: 待创建的Topic默认是否对所有用户都开启读写权限。true：（默认）所有用户都具备此 Topic 的读写权限。false：并非所有用户都具备此 Topic 的读写权限。默认情况下，用户对于此 Topic 的权限沿用用户的默认权限，如果默认权限不满足需求，您也可以通过 AccessPolicies 指定某个用户对于此 Topic 的自定义权限。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] cleanup_policies: Topic 的消息清理策略，支持以下三种取值方式：[delete]：默认的消息清理策略。在磁盘容量充足的情况下，保留在最长保留时间范围内的消息；在磁盘容量不足时，将提前删除旧消息，以保证服务可用性。[compact]：COMPACT 消息清理策略针对每个消息的 Key 进行整合，对于有相同 Key 的消息，只保留最新的 value 值，旧的记录则会被清除。[delete,compact]：同时配置 DELETE 和 COMPACT 两种消息清理策略。只要消息满足任一条清理策略时，都将被清除。
        :param pulumi.Input[builtins.str] created_time: Topic 的创建时间。
        :param pulumi.Input[builtins.str] description: Topic 的描述信息。长度不超过 128 个字符。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        :param pulumi.Input[builtins.int] log_retention_hours: 消息保留时长，单位小时。Topic维度的消息保留时长，取值范围：1   - 2160小时（90天）。
        :param pulumi.Input[builtins.str] parameters: Topic 级别的参数配置。Parameters 参数说明 MinInsyncReplicaNumber:2：最小同步副本个数。当同步副本个数小于配置值时，消息将无法写入对应 Topic。配置值越大，数据可靠性增加，但是可用性将会降低。默认值为副本数减 1。考虑到 Topic 的可用性，建议设置为副本数减 1。MessageMaxByte:12：最大消息大小。单位为 MB，取值范围为 1～12。默认沿用实例的最大消息大小设置。LogRetentionHours:72：消息保留时长。单位为小时，取值范围为 0～2160，即消息最久保留 90 天。默认沿用实例的消息保留时长设置。
        :param pulumi.Input[builtins.int] partition_number: Topic 分区数。取值范围为 1~300，如果实例中已创建了其他 Topic，则所有 Topic 的分区数之和不超过该实例的分区数上限。如果分区数无法满足业务需求，您可以购买更多分区，提升实例的分区数量上限。
        :param pulumi.Input[builtins.int] replica_number: Topic 副本个数。可设置为为 2 或 3，默认值为 3。
        :param pulumi.Input[builtins.str] status: Topic 的状态。
        :param pulumi.Input[builtins.str] topic_name: 待创建的 Topic 名称。3～64 个字符。必须以英文或数字开头。支持的字符包括英文、数字、连字符（-）、下划线（_）和英文句号（.）。
        :param pulumi.Input[builtins.float] used_storage_percentage_in_instance: 当前 Topic 总数据量占实例总存储空间的比例，控制台页面显示为保留两位小数的百分数。
        :param pulumi.Input[builtins.int] used_storage_space_in_bytes: 当前 Topic 已使用的总存储空间大小。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _TopicState.__new__(_TopicState)

        __props__.__dict__["access_policies"] = access_policies
        __props__.__dict__["all_authority"] = all_authority
        __props__.__dict__["cleanup_policies"] = cleanup_policies
        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["description"] = description
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["log_retention_hours"] = log_retention_hours
        __props__.__dict__["parameters"] = parameters
        __props__.__dict__["partition_number"] = partition_number
        __props__.__dict__["replica_number"] = replica_number
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["topic_name"] = topic_name
        __props__.__dict__["used_storage_percentage_in_instance"] = used_storage_percentage_in_instance
        __props__.__dict__["used_storage_space_in_bytes"] = used_storage_space_in_bytes
        return Topic(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accessPolicies")
    def access_policies(self) -> pulumi.Output[Sequence['outputs.TopicAccessPolicy']]:
        return pulumi.get(self, "access_policies")

    @property
    @pulumi.getter(name="allAuthority")
    def all_authority(self) -> pulumi.Output[builtins.bool]:
        """
        待创建的Topic默认是否对所有用户都开启读写权限。true：（默认）所有用户都具备此 Topic 的读写权限。false：并非所有用户都具备此 Topic 的读写权限。默认情况下，用户对于此 Topic 的权限沿用用户的默认权限，如果默认权限不满足需求，您也可以通过 AccessPolicies 指定某个用户对于此 Topic 的自定义权限。
        """
        return pulumi.get(self, "all_authority")

    @property
    @pulumi.getter(name="cleanupPolicies")
    def cleanup_policies(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        Topic 的消息清理策略，支持以下三种取值方式：[delete]：默认的消息清理策略。在磁盘容量充足的情况下，保留在最长保留时间范围内的消息；在磁盘容量不足时，将提前删除旧消息，以保证服务可用性。[compact]：COMPACT 消息清理策略针对每个消息的 Key 进行整合，对于有相同 Key 的消息，只保留最新的 value 值，旧的记录则会被清除。[delete,compact]：同时配置 DELETE 和 COMPACT 两种消息清理策略。只要消息满足任一条清理策略时，都将被清除。
        """
        return pulumi.get(self, "cleanup_policies")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        Topic 的创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        Topic 的描述信息。长度不超过 128 个字符。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[builtins.str]:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="logRetentionHours")
    def log_retention_hours(self) -> pulumi.Output[builtins.int]:
        """
        消息保留时长，单位小时。Topic维度的消息保留时长，取值范围：1   - 2160小时（90天）。
        """
        return pulumi.get(self, "log_retention_hours")

    @property
    @pulumi.getter
    def parameters(self) -> pulumi.Output[builtins.str]:
        """
        Topic 级别的参数配置。Parameters 参数说明 MinInsyncReplicaNumber:2：最小同步副本个数。当同步副本个数小于配置值时，消息将无法写入对应 Topic。配置值越大，数据可靠性增加，但是可用性将会降低。默认值为副本数减 1。考虑到 Topic 的可用性，建议设置为副本数减 1。MessageMaxByte:12：最大消息大小。单位为 MB，取值范围为 1～12。默认沿用实例的最大消息大小设置。LogRetentionHours:72：消息保留时长。单位为小时，取值范围为 0～2160，即消息最久保留 90 天。默认沿用实例的消息保留时长设置。
        """
        return pulumi.get(self, "parameters")

    @property
    @pulumi.getter(name="partitionNumber")
    def partition_number(self) -> pulumi.Output[builtins.int]:
        """
        Topic 分区数。取值范围为 1~300，如果实例中已创建了其他 Topic，则所有 Topic 的分区数之和不超过该实例的分区数上限。如果分区数无法满足业务需求，您可以购买更多分区，提升实例的分区数量上限。
        """
        return pulumi.get(self, "partition_number")

    @property
    @pulumi.getter(name="replicaNumber")
    def replica_number(self) -> pulumi.Output[builtins.int]:
        """
        Topic 副本个数。可设置为为 2 或 3，默认值为 3。
        """
        return pulumi.get(self, "replica_number")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        Topic 的状态。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.TopicTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="topicName")
    def topic_name(self) -> pulumi.Output[builtins.str]:
        """
        待创建的 Topic 名称。3～64 个字符。必须以英文或数字开头。支持的字符包括英文、数字、连字符（-）、下划线（_）和英文句号（.）。
        """
        return pulumi.get(self, "topic_name")

    @property
    @pulumi.getter(name="usedStoragePercentageInInstance")
    def used_storage_percentage_in_instance(self) -> pulumi.Output[builtins.float]:
        """
        当前 Topic 总数据量占实例总存储空间的比例，控制台页面显示为保留两位小数的百分数。
        """
        return pulumi.get(self, "used_storage_percentage_in_instance")

    @property
    @pulumi.getter(name="usedStorageSpaceInBytes")
    def used_storage_space_in_bytes(self) -> pulumi.Output[builtins.int]:
        """
        当前 Topic 已使用的总存储空间大小。
        """
        return pulumi.get(self, "used_storage_space_in_bytes")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'SnapshotTag',
    'VolumeBaselinePerformance',
    'VolumeExtraPerformance',
    'VolumeTag',
    'VolumeTotalPerformance',
    'GetSnapshotTagResult',
    'GetVolumeBaselinePerformanceResult',
    'GetVolumeExtraPerformanceResult',
    'GetVolumeTagResult',
    'GetVolumeTotalPerformanceResult',
]

@pulumi.output_type
class SnapshotTag(dict):
    def __init__(__self__, *,
                 key: Optional[builtins.str] = None,
                 value: Optional[builtins.str] = None):
        """
        :param builtins.str key: 为资源添加的用户标签的标签键。命名规则如下：不能以任何大小写形式的volc:或sys:开头。volc:或sys:开头为系统预留标签键禁止创建。只能包含语言字符、数字、空格和英文符号“_”、“.”、“:”、“/”、“=”、“+”、“-”、“@”。长度限制在1～128个字符之间。
        :param builtins.str value: 为资源添加的用户标签的标签值。命名规则如下：只能包含语言字符、数字、空格和英文符号“_”、“.”、“:”、“/”、“=”、“+”、“-”、“@”。允许为空，长度限制在0～256个字符之间。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[builtins.str]:
        """
        为资源添加的用户标签的标签键。命名规则如下：不能以任何大小写形式的volc:或sys:开头。volc:或sys:开头为系统预留标签键禁止创建。只能包含语言字符、数字、空格和英文符号“_”、“.”、“:”、“/”、“=”、“+”、“-”、“@”。长度限制在1～128个字符之间。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> Optional[builtins.str]:
        """
        为资源添加的用户标签的标签值。命名规则如下：只能包含语言字符、数字、空格和英文符号“_”、“.”、“:”、“/”、“=”、“+”、“-”、“@”。允许为空，长度限制在0～256个字符之间。
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class VolumeBaselinePerformance(dict):
    def __init__(__self__, *,
                 iops: Optional[builtins.float] = None,
                 throughput: Optional[builtins.float] = None):
        """
        :param builtins.float iops: 云盘的总IOPS，即云盘的基准IOPS和额外IOPS之和。
        :param builtins.float throughput: 云盘的总吞吐量，即云盘的基准吞吐量和额外吞吐量之和。
        """
        if iops is not None:
            pulumi.set(__self__, "iops", iops)
        if throughput is not None:
            pulumi.set(__self__, "throughput", throughput)

    @property
    @pulumi.getter
    def iops(self) -> Optional[builtins.float]:
        """
        云盘的总IOPS，即云盘的基准IOPS和额外IOPS之和。
        """
        return pulumi.get(self, "iops")

    @property
    @pulumi.getter
    def throughput(self) -> Optional[builtins.float]:
        """
        云盘的总吞吐量，即云盘的基准吞吐量和额外吞吐量之和。
        """
        return pulumi.get(self, "throughput")


@pulumi.output_type
class VolumeExtraPerformance(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "extraPerformanceTypeId":
            suggest = "extra_performance_type_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in VolumeExtraPerformance. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        VolumeExtraPerformance.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        VolumeExtraPerformance.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 extra_performance_type_id: Optional[builtins.str] = None,
                 iops: Optional[builtins.float] = None,
                 throughput: Optional[builtins.float] = None):
        """
        :param builtins.str extra_performance_type_id: 额外性能的类型，取值如下：Balance：均衡型额外性能；IOPS：IOPS型额外性能；Throughput：吞吐量型额外性能。
        :param builtins.float iops: 云盘的额外IOPS。
        :param builtins.float throughput: 云盘的额外吞吐量。
        """
        if extra_performance_type_id is not None:
            pulumi.set(__self__, "extra_performance_type_id", extra_performance_type_id)
        if iops is not None:
            pulumi.set(__self__, "iops", iops)
        if throughput is not None:
            pulumi.set(__self__, "throughput", throughput)

    @property
    @pulumi.getter(name="extraPerformanceTypeId")
    def extra_performance_type_id(self) -> Optional[builtins.str]:
        """
        额外性能的类型，取值如下：Balance：均衡型额外性能；IOPS：IOPS型额外性能；Throughput：吞吐量型额外性能。
        """
        return pulumi.get(self, "extra_performance_type_id")

    @property
    @pulumi.getter
    def iops(self) -> Optional[builtins.float]:
        """
        云盘的额外IOPS。
        """
        return pulumi.get(self, "iops")

    @property
    @pulumi.getter
    def throughput(self) -> Optional[builtins.float]:
        """
        云盘的额外吞吐量。
        """
        return pulumi.get(self, "throughput")


@pulumi.output_type
class VolumeTag(dict):
    def __init__(__self__, *,
                 key: Optional[builtins.str] = None,
                 value: Optional[builtins.str] = None):
        """
        :param builtins.str key: 标签键。
        :param builtins.str value: 标签值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[builtins.str]:
        """
        标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> Optional[builtins.str]:
        """
        标签值。
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class VolumeTotalPerformance(dict):
    def __init__(__self__, *,
                 iops: Optional[builtins.float] = None,
                 throughput: Optional[builtins.float] = None):
        """
        :param builtins.float iops: 云盘的总IOPS，即云盘的基准IOPS和额外IOPS之和。
        :param builtins.float throughput: 云盘的总吞吐量，即云盘的基准吞吐量和额外吞吐量之和。
        """
        if iops is not None:
            pulumi.set(__self__, "iops", iops)
        if throughput is not None:
            pulumi.set(__self__, "throughput", throughput)

    @property
    @pulumi.getter
    def iops(self) -> Optional[builtins.float]:
        """
        云盘的总IOPS，即云盘的基准IOPS和额外IOPS之和。
        """
        return pulumi.get(self, "iops")

    @property
    @pulumi.getter
    def throughput(self) -> Optional[builtins.float]:
        """
        云盘的总吞吐量，即云盘的基准吞吐量和额外吞吐量之和。
        """
        return pulumi.get(self, "throughput")


@pulumi.output_type
class GetSnapshotTagResult(dict):
    def __init__(__self__, *,
                 key: builtins.str,
                 value: builtins.str):
        """
        :param builtins.str key: 为资源添加的用户标签的标签键。命名规则如下：不能以任何大小写形式的volc:或sys:开头。volc:或sys:开头为系统预留标签键禁止创建。只能包含语言字符、数字、空格和英文符号“_”、“.”、“:”、“/”、“=”、“+”、“-”、“@”。长度限制在1～128个字符之间。
        :param builtins.str value: 为资源添加的用户标签的标签值。命名规则如下：只能包含语言字符、数字、空格和英文符号“_”、“.”、“:”、“/”、“=”、“+”、“-”、“@”。允许为空，长度限制在0～256个字符之间。
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> builtins.str:
        """
        为资源添加的用户标签的标签键。命名规则如下：不能以任何大小写形式的volc:或sys:开头。volc:或sys:开头为系统预留标签键禁止创建。只能包含语言字符、数字、空格和英文符号“_”、“.”、“:”、“/”、“=”、“+”、“-”、“@”。长度限制在1～128个字符之间。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> builtins.str:
        """
        为资源添加的用户标签的标签值。命名规则如下：只能包含语言字符、数字、空格和英文符号“_”、“.”、“:”、“/”、“=”、“+”、“-”、“@”。允许为空，长度限制在0～256个字符之间。
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetVolumeBaselinePerformanceResult(dict):
    def __init__(__self__, *,
                 iops: builtins.float,
                 throughput: builtins.float):
        """
        :param builtins.float iops: 云盘的总IOPS，即云盘的基准IOPS和额外IOPS之和。
        :param builtins.float throughput: 云盘的总吞吐量，即云盘的基准吞吐量和额外吞吐量之和。
        """
        pulumi.set(__self__, "iops", iops)
        pulumi.set(__self__, "throughput", throughput)

    @property
    @pulumi.getter
    def iops(self) -> builtins.float:
        """
        云盘的总IOPS，即云盘的基准IOPS和额外IOPS之和。
        """
        return pulumi.get(self, "iops")

    @property
    @pulumi.getter
    def throughput(self) -> builtins.float:
        """
        云盘的总吞吐量，即云盘的基准吞吐量和额外吞吐量之和。
        """
        return pulumi.get(self, "throughput")


@pulumi.output_type
class GetVolumeExtraPerformanceResult(dict):
    def __init__(__self__, *,
                 extra_performance_type_id: builtins.str,
                 iops: builtins.float,
                 throughput: builtins.float):
        """
        :param builtins.str extra_performance_type_id: 额外性能的类型，取值如下：Balance：均衡型额外性能；IOPS：IOPS型额外性能；Throughput：吞吐量型额外性能。
        :param builtins.float iops: 云盘的额外IOPS。
        :param builtins.float throughput: 云盘的额外吞吐量。
        """
        pulumi.set(__self__, "extra_performance_type_id", extra_performance_type_id)
        pulumi.set(__self__, "iops", iops)
        pulumi.set(__self__, "throughput", throughput)

    @property
    @pulumi.getter(name="extraPerformanceTypeId")
    def extra_performance_type_id(self) -> builtins.str:
        """
        额外性能的类型，取值如下：Balance：均衡型额外性能；IOPS：IOPS型额外性能；Throughput：吞吐量型额外性能。
        """
        return pulumi.get(self, "extra_performance_type_id")

    @property
    @pulumi.getter
    def iops(self) -> builtins.float:
        """
        云盘的额外IOPS。
        """
        return pulumi.get(self, "iops")

    @property
    @pulumi.getter
    def throughput(self) -> builtins.float:
        """
        云盘的额外吞吐量。
        """
        return pulumi.get(self, "throughput")


@pulumi.output_type
class GetVolumeTagResult(dict):
    def __init__(__self__, *,
                 key: builtins.str,
                 value: builtins.str):
        """
        :param builtins.str key: 标签键。
        :param builtins.str value: 标签值。
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> builtins.str:
        """
        标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> builtins.str:
        """
        标签值。
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetVolumeTotalPerformanceResult(dict):
    def __init__(__self__, *,
                 iops: builtins.float,
                 throughput: builtins.float):
        """
        :param builtins.float iops: 云盘的总IOPS，即云盘的基准IOPS和额外IOPS之和。
        :param builtins.float throughput: 云盘的总吞吐量，即云盘的基准吞吐量和额外吞吐量之和。
        """
        pulumi.set(__self__, "iops", iops)
        pulumi.set(__self__, "throughput", throughput)

    @property
    @pulumi.getter
    def iops(self) -> builtins.float:
        """
        云盘的总IOPS，即云盘的基准IOPS和额外IOPS之和。
        """
        return pulumi.get(self, "iops")

    @property
    @pulumi.getter
    def throughput(self) -> builtins.float:
        """
        云盘的总吞吐量，即云盘的基准吞吐量和额外吞吐量之和。
        """
        return pulumi.get(self, "throughput")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ClusterArgs', 'Cluster']

@pulumi.input_type
class ClusterArgs:
    def __init__(__self__, *,
                 name: pulumi.Input[builtins.str],
                 cluster_config: Optional[pulumi.Input['ClusterClusterConfigArgs']] = None,
                 delete_protection_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 kubernetes_version: Optional[pulumi.Input[builtins.str]] = None,
                 kubernetes_version_create: Optional[pulumi.Input[builtins.str]] = None,
                 logging_config: Optional[pulumi.Input['ClusterLoggingConfigArgs']] = None,
                 monitoring_config: Optional[pulumi.Input['ClusterMonitoringConfigArgs']] = None,
                 pods_config: Optional[pulumi.Input['ClusterPodsConfigArgs']] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 services_config: Optional[pulumi.Input['ClusterServicesConfigArgs']] = None,
                 source_region: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['ClusterTagArgs']]]] = None):
        """
        The set of arguments for constructing a Cluster resource.
        :param pulumi.Input[builtins.str] name: 集群名称。同一个地域下，名称必须唯一。支持大小写英文字母、汉字、数字、短划线（-），长度限制为 2～64 个字符。
        :param pulumi.Input['ClusterClusterConfigArgs'] cluster_config: 集群控制面及部分节点的网络配置。
        :param pulumi.Input[builtins.bool] delete_protection_enabled: 集群删除保护，取值：false：（默认值）关闭删除保护。true：开启删除保护，不允许直接删除集群。
        :param pulumi.Input[builtins.str] description: 集群描述。长度限制为 300 个字符以内。
        :param pulumi.Input[builtins.str] kubernetes_version: 集群的 Kubernetes 版本，格式为x.xx。创建集群时，系统自动匹配该 Kubernetes 版本对应的最新 VKE 版本。（查询使用）
        :param pulumi.Input[builtins.str] kubernetes_version_create: 集群的 Kubernetes 版本，格式为x.xx。创建集群时，系统自动匹配该 Kubernetes 版本对应的最新 VKE 版本。(创建使用)
        :param pulumi.Input['ClusterLoggingConfigArgs'] logging_config: 集群的日志配置信息。
        :param pulumi.Input['ClusterMonitoringConfigArgs'] monitoring_config: 监控配置信息。
        :param pulumi.Input['ClusterPodsConfigArgs'] pods_config: Pod 的网络配置。
        :param pulumi.Input[builtins.str] project_name: 集群所属项目名称，一个集群只能归属于一个项目。只能包含英文字母、数字、下划线（_）、英文句点（.）和中划线（-）。长度限制在 64 个字符以内。默认值：default。
        :param pulumi.Input['ClusterServicesConfigArgs'] services_config: 服务的网络配置。
        :param pulumi.Input[builtins.str] source_region: 集群源地域。
        """
        pulumi.set(__self__, "name", name)
        if cluster_config is not None:
            pulumi.set(__self__, "cluster_config", cluster_config)
        if delete_protection_enabled is not None:
            pulumi.set(__self__, "delete_protection_enabled", delete_protection_enabled)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if kubernetes_version is not None:
            pulumi.set(__self__, "kubernetes_version", kubernetes_version)
        if kubernetes_version_create is not None:
            pulumi.set(__self__, "kubernetes_version_create", kubernetes_version_create)
        if logging_config is not None:
            pulumi.set(__self__, "logging_config", logging_config)
        if monitoring_config is not None:
            pulumi.set(__self__, "monitoring_config", monitoring_config)
        if pods_config is not None:
            pulumi.set(__self__, "pods_config", pods_config)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if services_config is not None:
            pulumi.set(__self__, "services_config", services_config)
        if source_region is not None:
            pulumi.set(__self__, "source_region", source_region)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[builtins.str]:
        """
        集群名称。同一个地域下，名称必须唯一。支持大小写英文字母、汉字、数字、短划线（-），长度限制为 2～64 个字符。
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="clusterConfig")
    def cluster_config(self) -> Optional[pulumi.Input['ClusterClusterConfigArgs']]:
        """
        集群控制面及部分节点的网络配置。
        """
        return pulumi.get(self, "cluster_config")

    @cluster_config.setter
    def cluster_config(self, value: Optional[pulumi.Input['ClusterClusterConfigArgs']]):
        pulumi.set(self, "cluster_config", value)

    @property
    @pulumi.getter(name="deleteProtectionEnabled")
    def delete_protection_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        集群删除保护，取值：false：（默认值）关闭删除保护。true：开启删除保护，不允许直接删除集群。
        """
        return pulumi.get(self, "delete_protection_enabled")

    @delete_protection_enabled.setter
    def delete_protection_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "delete_protection_enabled", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        集群描述。长度限制为 300 个字符以内。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="kubernetesVersion")
    def kubernetes_version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        集群的 Kubernetes 版本，格式为x.xx。创建集群时，系统自动匹配该 Kubernetes 版本对应的最新 VKE 版本。（查询使用）
        """
        return pulumi.get(self, "kubernetes_version")

    @kubernetes_version.setter
    def kubernetes_version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "kubernetes_version", value)

    @property
    @pulumi.getter(name="kubernetesVersionCreate")
    def kubernetes_version_create(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        集群的 Kubernetes 版本，格式为x.xx。创建集群时，系统自动匹配该 Kubernetes 版本对应的最新 VKE 版本。(创建使用)
        """
        return pulumi.get(self, "kubernetes_version_create")

    @kubernetes_version_create.setter
    def kubernetes_version_create(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "kubernetes_version_create", value)

    @property
    @pulumi.getter(name="loggingConfig")
    def logging_config(self) -> Optional[pulumi.Input['ClusterLoggingConfigArgs']]:
        """
        集群的日志配置信息。
        """
        return pulumi.get(self, "logging_config")

    @logging_config.setter
    def logging_config(self, value: Optional[pulumi.Input['ClusterLoggingConfigArgs']]):
        pulumi.set(self, "logging_config", value)

    @property
    @pulumi.getter(name="monitoringConfig")
    def monitoring_config(self) -> Optional[pulumi.Input['ClusterMonitoringConfigArgs']]:
        """
        监控配置信息。
        """
        return pulumi.get(self, "monitoring_config")

    @monitoring_config.setter
    def monitoring_config(self, value: Optional[pulumi.Input['ClusterMonitoringConfigArgs']]):
        pulumi.set(self, "monitoring_config", value)

    @property
    @pulumi.getter(name="podsConfig")
    def pods_config(self) -> Optional[pulumi.Input['ClusterPodsConfigArgs']]:
        """
        Pod 的网络配置。
        """
        return pulumi.get(self, "pods_config")

    @pods_config.setter
    def pods_config(self, value: Optional[pulumi.Input['ClusterPodsConfigArgs']]):
        pulumi.set(self, "pods_config", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        集群所属项目名称，一个集群只能归属于一个项目。只能包含英文字母、数字、下划线（_）、英文句点（.）和中划线（-）。长度限制在 64 个字符以内。默认值：default。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="servicesConfig")
    def services_config(self) -> Optional[pulumi.Input['ClusterServicesConfigArgs']]:
        """
        服务的网络配置。
        """
        return pulumi.get(self, "services_config")

    @services_config.setter
    def services_config(self, value: Optional[pulumi.Input['ClusterServicesConfigArgs']]):
        pulumi.set(self, "services_config", value)

    @property
    @pulumi.getter(name="sourceRegion")
    def source_region(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        集群源地域。
        """
        return pulumi.get(self, "source_region")

    @source_region.setter
    def source_region(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "source_region", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ClusterTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ClusterTagArgs']]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _ClusterState:
    def __init__(__self__, *,
                 cluster_config: Optional[pulumi.Input['ClusterClusterConfigArgs']] = None,
                 cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 delete_protection_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 kubernetes_version: Optional[pulumi.Input[builtins.str]] = None,
                 kubernetes_version_create: Optional[pulumi.Input[builtins.str]] = None,
                 logging_config: Optional[pulumi.Input['ClusterLoggingConfigArgs']] = None,
                 message: Optional[pulumi.Input[builtins.str]] = None,
                 monitoring_config: Optional[pulumi.Input['ClusterMonitoringConfigArgs']] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 node_statistics: Optional[pulumi.Input['ClusterNodeStatisticsArgs']] = None,
                 pods_config: Optional[pulumi.Input['ClusterPodsConfigArgs']] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 services_config: Optional[pulumi.Input['ClusterServicesConfigArgs']] = None,
                 source_region: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input['ClusterStatusArgs']] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['ClusterTagArgs']]]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 updated_time: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Cluster resources.
        :param pulumi.Input['ClusterClusterConfigArgs'] cluster_config: 集群控制面及部分节点的网络配置。
        :param pulumi.Input[builtins.str] cluster_id: 集群 ID。
        :param pulumi.Input[builtins.str] created_time: 集群创建时间。标准 RFC3339 格式的 UTC+0 时间。
        :param pulumi.Input[builtins.bool] delete_protection_enabled: 集群删除保护，取值：false：（默认值）关闭删除保护。true：开启删除保护，不允许直接删除集群。
        :param pulumi.Input[builtins.str] description: 集群描述。长度限制为 300 个字符以内。
        :param pulumi.Input[builtins.str] kubernetes_version: 集群的 Kubernetes 版本，格式为x.xx。创建集群时，系统自动匹配该 Kubernetes 版本对应的最新 VKE 版本。（查询使用）
        :param pulumi.Input[builtins.str] kubernetes_version_create: 集群的 Kubernetes 版本，格式为x.xx。创建集群时，系统自动匹配该 Kubernetes 版本对应的最新 VKE 版本。(创建使用)
        :param pulumi.Input['ClusterLoggingConfigArgs'] logging_config: 集群的日志配置信息。
        :param pulumi.Input[builtins.str] message: 集群状态描述。
        :param pulumi.Input['ClusterMonitoringConfigArgs'] monitoring_config: 监控配置信息。
        :param pulumi.Input[builtins.str] name: 集群名称。同一个地域下，名称必须唯一。支持大小写英文字母、汉字、数字、短划线（-），长度限制为 2～64 个字符。
        :param pulumi.Input['ClusterNodeStatisticsArgs'] node_statistics: 集群中各主状态下对应的节点数量统计。
        :param pulumi.Input['ClusterPodsConfigArgs'] pods_config: Pod 的网络配置。
        :param pulumi.Input[builtins.str] project_name: 集群所属项目名称，一个集群只能归属于一个项目。只能包含英文字母、数字、下划线（_）、英文句点（.）和中划线（-）。长度限制在 64 个字符以内。默认值：default。
        :param pulumi.Input['ClusterServicesConfigArgs'] services_config: 服务的网络配置。
        :param pulumi.Input[builtins.str] source_region: 集群源地域。
        :param pulumi.Input['ClusterStatusArgs'] status: 集群状态。
        :param pulumi.Input[builtins.str] type: 集群类型。
        :param pulumi.Input[builtins.str] updated_time: 集群最近一次更新的时间。标准 RFC3339 格式的 UTC+0 时间。
        """
        if cluster_config is not None:
            pulumi.set(__self__, "cluster_config", cluster_config)
        if cluster_id is not None:
            pulumi.set(__self__, "cluster_id", cluster_id)
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if delete_protection_enabled is not None:
            pulumi.set(__self__, "delete_protection_enabled", delete_protection_enabled)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if kubernetes_version is not None:
            pulumi.set(__self__, "kubernetes_version", kubernetes_version)
        if kubernetes_version_create is not None:
            pulumi.set(__self__, "kubernetes_version_create", kubernetes_version_create)
        if logging_config is not None:
            pulumi.set(__self__, "logging_config", logging_config)
        if message is not None:
            pulumi.set(__self__, "message", message)
        if monitoring_config is not None:
            pulumi.set(__self__, "monitoring_config", monitoring_config)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if node_statistics is not None:
            pulumi.set(__self__, "node_statistics", node_statistics)
        if pods_config is not None:
            pulumi.set(__self__, "pods_config", pods_config)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if services_config is not None:
            pulumi.set(__self__, "services_config", services_config)
        if source_region is not None:
            pulumi.set(__self__, "source_region", source_region)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if updated_time is not None:
            pulumi.set(__self__, "updated_time", updated_time)

    @property
    @pulumi.getter(name="clusterConfig")
    def cluster_config(self) -> Optional[pulumi.Input['ClusterClusterConfigArgs']]:
        """
        集群控制面及部分节点的网络配置。
        """
        return pulumi.get(self, "cluster_config")

    @cluster_config.setter
    def cluster_config(self, value: Optional[pulumi.Input['ClusterClusterConfigArgs']]):
        pulumi.set(self, "cluster_config", value)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        集群 ID。
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cluster_id", value)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        集群创建时间。标准 RFC3339 格式的 UTC+0 时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter(name="deleteProtectionEnabled")
    def delete_protection_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        集群删除保护，取值：false：（默认值）关闭删除保护。true：开启删除保护，不允许直接删除集群。
        """
        return pulumi.get(self, "delete_protection_enabled")

    @delete_protection_enabled.setter
    def delete_protection_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "delete_protection_enabled", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        集群描述。长度限制为 300 个字符以内。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="kubernetesVersion")
    def kubernetes_version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        集群的 Kubernetes 版本，格式为x.xx。创建集群时，系统自动匹配该 Kubernetes 版本对应的最新 VKE 版本。（查询使用）
        """
        return pulumi.get(self, "kubernetes_version")

    @kubernetes_version.setter
    def kubernetes_version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "kubernetes_version", value)

    @property
    @pulumi.getter(name="kubernetesVersionCreate")
    def kubernetes_version_create(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        集群的 Kubernetes 版本，格式为x.xx。创建集群时，系统自动匹配该 Kubernetes 版本对应的最新 VKE 版本。(创建使用)
        """
        return pulumi.get(self, "kubernetes_version_create")

    @kubernetes_version_create.setter
    def kubernetes_version_create(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "kubernetes_version_create", value)

    @property
    @pulumi.getter(name="loggingConfig")
    def logging_config(self) -> Optional[pulumi.Input['ClusterLoggingConfigArgs']]:
        """
        集群的日志配置信息。
        """
        return pulumi.get(self, "logging_config")

    @logging_config.setter
    def logging_config(self, value: Optional[pulumi.Input['ClusterLoggingConfigArgs']]):
        pulumi.set(self, "logging_config", value)

    @property
    @pulumi.getter
    def message(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        集群状态描述。
        """
        return pulumi.get(self, "message")

    @message.setter
    def message(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "message", value)

    @property
    @pulumi.getter(name="monitoringConfig")
    def monitoring_config(self) -> Optional[pulumi.Input['ClusterMonitoringConfigArgs']]:
        """
        监控配置信息。
        """
        return pulumi.get(self, "monitoring_config")

    @monitoring_config.setter
    def monitoring_config(self, value: Optional[pulumi.Input['ClusterMonitoringConfigArgs']]):
        pulumi.set(self, "monitoring_config", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        集群名称。同一个地域下，名称必须唯一。支持大小写英文字母、汉字、数字、短划线（-），长度限制为 2～64 个字符。
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="nodeStatistics")
    def node_statistics(self) -> Optional[pulumi.Input['ClusterNodeStatisticsArgs']]:
        """
        集群中各主状态下对应的节点数量统计。
        """
        return pulumi.get(self, "node_statistics")

    @node_statistics.setter
    def node_statistics(self, value: Optional[pulumi.Input['ClusterNodeStatisticsArgs']]):
        pulumi.set(self, "node_statistics", value)

    @property
    @pulumi.getter(name="podsConfig")
    def pods_config(self) -> Optional[pulumi.Input['ClusterPodsConfigArgs']]:
        """
        Pod 的网络配置。
        """
        return pulumi.get(self, "pods_config")

    @pods_config.setter
    def pods_config(self, value: Optional[pulumi.Input['ClusterPodsConfigArgs']]):
        pulumi.set(self, "pods_config", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        集群所属项目名称，一个集群只能归属于一个项目。只能包含英文字母、数字、下划线（_）、英文句点（.）和中划线（-）。长度限制在 64 个字符以内。默认值：default。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="servicesConfig")
    def services_config(self) -> Optional[pulumi.Input['ClusterServicesConfigArgs']]:
        """
        服务的网络配置。
        """
        return pulumi.get(self, "services_config")

    @services_config.setter
    def services_config(self, value: Optional[pulumi.Input['ClusterServicesConfigArgs']]):
        pulumi.set(self, "services_config", value)

    @property
    @pulumi.getter(name="sourceRegion")
    def source_region(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        集群源地域。
        """
        return pulumi.get(self, "source_region")

    @source_region.setter
    def source_region(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "source_region", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input['ClusterStatusArgs']]:
        """
        集群状态。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input['ClusterStatusArgs']]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ClusterTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ClusterTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        集群类型。
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        集群最近一次更新的时间。标准 RFC3339 格式的 UTC+0 时间。
        """
        return pulumi.get(self, "updated_time")

    @updated_time.setter
    def updated_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_time", value)


@pulumi.type_token("bytepluscc:vke/cluster:Cluster")
class Cluster(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_config: Optional[pulumi.Input[Union['ClusterClusterConfigArgs', 'ClusterClusterConfigArgsDict']]] = None,
                 delete_protection_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 kubernetes_version: Optional[pulumi.Input[builtins.str]] = None,
                 kubernetes_version_create: Optional[pulumi.Input[builtins.str]] = None,
                 logging_config: Optional[pulumi.Input[Union['ClusterLoggingConfigArgs', 'ClusterLoggingConfigArgsDict']]] = None,
                 monitoring_config: Optional[pulumi.Input[Union['ClusterMonitoringConfigArgs', 'ClusterMonitoringConfigArgsDict']]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 pods_config: Optional[pulumi.Input[Union['ClusterPodsConfigArgs', 'ClusterPodsConfigArgsDict']]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 services_config: Optional[pulumi.Input[Union['ClusterServicesConfigArgs', 'ClusterServicesConfigArgsDict']]] = None,
                 source_region: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ClusterTagArgs', 'ClusterTagArgsDict']]]]] = None,
                 __props__=None):
        """
        容器服务通过深度融合新一代云原生技术，提供以容器为核心的高性能 Kubernetes 容器集群管理服务。在云端一键构建高可用 Kubernetes 集群，并实现容器化应用的可视化全生命周期管理，助力用户快速构建容器化应用。

        ## Import

        ```sh
        $ pulumi import bytepluscc:vke/cluster:Cluster example "cluster_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['ClusterClusterConfigArgs', 'ClusterClusterConfigArgsDict']] cluster_config: 集群控制面及部分节点的网络配置。
        :param pulumi.Input[builtins.bool] delete_protection_enabled: 集群删除保护，取值：false：（默认值）关闭删除保护。true：开启删除保护，不允许直接删除集群。
        :param pulumi.Input[builtins.str] description: 集群描述。长度限制为 300 个字符以内。
        :param pulumi.Input[builtins.str] kubernetes_version: 集群的 Kubernetes 版本，格式为x.xx。创建集群时，系统自动匹配该 Kubernetes 版本对应的最新 VKE 版本。（查询使用）
        :param pulumi.Input[builtins.str] kubernetes_version_create: 集群的 Kubernetes 版本，格式为x.xx。创建集群时，系统自动匹配该 Kubernetes 版本对应的最新 VKE 版本。(创建使用)
        :param pulumi.Input[Union['ClusterLoggingConfigArgs', 'ClusterLoggingConfigArgsDict']] logging_config: 集群的日志配置信息。
        :param pulumi.Input[Union['ClusterMonitoringConfigArgs', 'ClusterMonitoringConfigArgsDict']] monitoring_config: 监控配置信息。
        :param pulumi.Input[builtins.str] name: 集群名称。同一个地域下，名称必须唯一。支持大小写英文字母、汉字、数字、短划线（-），长度限制为 2～64 个字符。
        :param pulumi.Input[Union['ClusterPodsConfigArgs', 'ClusterPodsConfigArgsDict']] pods_config: Pod 的网络配置。
        :param pulumi.Input[builtins.str] project_name: 集群所属项目名称，一个集群只能归属于一个项目。只能包含英文字母、数字、下划线（_）、英文句点（.）和中划线（-）。长度限制在 64 个字符以内。默认值：default。
        :param pulumi.Input[Union['ClusterServicesConfigArgs', 'ClusterServicesConfigArgsDict']] services_config: 服务的网络配置。
        :param pulumi.Input[builtins.str] source_region: 集群源地域。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ClusterArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        容器服务通过深度融合新一代云原生技术，提供以容器为核心的高性能 Kubernetes 容器集群管理服务。在云端一键构建高可用 Kubernetes 集群，并实现容器化应用的可视化全生命周期管理，助力用户快速构建容器化应用。

        ## Import

        ```sh
        $ pulumi import bytepluscc:vke/cluster:Cluster example "cluster_id"
        ```

        :param str resource_name: The name of the resource.
        :param ClusterArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ClusterArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_config: Optional[pulumi.Input[Union['ClusterClusterConfigArgs', 'ClusterClusterConfigArgsDict']]] = None,
                 delete_protection_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 kubernetes_version: Optional[pulumi.Input[builtins.str]] = None,
                 kubernetes_version_create: Optional[pulumi.Input[builtins.str]] = None,
                 logging_config: Optional[pulumi.Input[Union['ClusterLoggingConfigArgs', 'ClusterLoggingConfigArgsDict']]] = None,
                 monitoring_config: Optional[pulumi.Input[Union['ClusterMonitoringConfigArgs', 'ClusterMonitoringConfigArgsDict']]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 pods_config: Optional[pulumi.Input[Union['ClusterPodsConfigArgs', 'ClusterPodsConfigArgsDict']]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 services_config: Optional[pulumi.Input[Union['ClusterServicesConfigArgs', 'ClusterServicesConfigArgsDict']]] = None,
                 source_region: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ClusterTagArgs', 'ClusterTagArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ClusterArgs.__new__(ClusterArgs)

            __props__.__dict__["cluster_config"] = cluster_config
            __props__.__dict__["delete_protection_enabled"] = delete_protection_enabled
            __props__.__dict__["description"] = description
            __props__.__dict__["kubernetes_version"] = kubernetes_version
            __props__.__dict__["kubernetes_version_create"] = kubernetes_version_create
            __props__.__dict__["logging_config"] = logging_config
            __props__.__dict__["monitoring_config"] = monitoring_config
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
            __props__.__dict__["pods_config"] = pods_config
            __props__.__dict__["project_name"] = project_name
            __props__.__dict__["services_config"] = services_config
            __props__.__dict__["source_region"] = source_region
            __props__.__dict__["tags"] = tags
            __props__.__dict__["cluster_id"] = None
            __props__.__dict__["created_time"] = None
            __props__.__dict__["message"] = None
            __props__.__dict__["node_statistics"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["type"] = None
            __props__.__dict__["updated_time"] = None
        super(Cluster, __self__).__init__(
            'bytepluscc:vke/cluster:Cluster',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cluster_config: Optional[pulumi.Input[Union['ClusterClusterConfigArgs', 'ClusterClusterConfigArgsDict']]] = None,
            cluster_id: Optional[pulumi.Input[builtins.str]] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            delete_protection_enabled: Optional[pulumi.Input[builtins.bool]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            kubernetes_version: Optional[pulumi.Input[builtins.str]] = None,
            kubernetes_version_create: Optional[pulumi.Input[builtins.str]] = None,
            logging_config: Optional[pulumi.Input[Union['ClusterLoggingConfigArgs', 'ClusterLoggingConfigArgsDict']]] = None,
            message: Optional[pulumi.Input[builtins.str]] = None,
            monitoring_config: Optional[pulumi.Input[Union['ClusterMonitoringConfigArgs', 'ClusterMonitoringConfigArgsDict']]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            node_statistics: Optional[pulumi.Input[Union['ClusterNodeStatisticsArgs', 'ClusterNodeStatisticsArgsDict']]] = None,
            pods_config: Optional[pulumi.Input[Union['ClusterPodsConfigArgs', 'ClusterPodsConfigArgsDict']]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            services_config: Optional[pulumi.Input[Union['ClusterServicesConfigArgs', 'ClusterServicesConfigArgsDict']]] = None,
            source_region: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[Union['ClusterStatusArgs', 'ClusterStatusArgsDict']]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ClusterTagArgs', 'ClusterTagArgsDict']]]]] = None,
            type: Optional[pulumi.Input[builtins.str]] = None,
            updated_time: Optional[pulumi.Input[builtins.str]] = None) -> 'Cluster':
        """
        Get an existing Cluster resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['ClusterClusterConfigArgs', 'ClusterClusterConfigArgsDict']] cluster_config: 集群控制面及部分节点的网络配置。
        :param pulumi.Input[builtins.str] cluster_id: 集群 ID。
        :param pulumi.Input[builtins.str] created_time: 集群创建时间。标准 RFC3339 格式的 UTC+0 时间。
        :param pulumi.Input[builtins.bool] delete_protection_enabled: 集群删除保护，取值：false：（默认值）关闭删除保护。true：开启删除保护，不允许直接删除集群。
        :param pulumi.Input[builtins.str] description: 集群描述。长度限制为 300 个字符以内。
        :param pulumi.Input[builtins.str] kubernetes_version: 集群的 Kubernetes 版本，格式为x.xx。创建集群时，系统自动匹配该 Kubernetes 版本对应的最新 VKE 版本。（查询使用）
        :param pulumi.Input[builtins.str] kubernetes_version_create: 集群的 Kubernetes 版本，格式为x.xx。创建集群时，系统自动匹配该 Kubernetes 版本对应的最新 VKE 版本。(创建使用)
        :param pulumi.Input[Union['ClusterLoggingConfigArgs', 'ClusterLoggingConfigArgsDict']] logging_config: 集群的日志配置信息。
        :param pulumi.Input[builtins.str] message: 集群状态描述。
        :param pulumi.Input[Union['ClusterMonitoringConfigArgs', 'ClusterMonitoringConfigArgsDict']] monitoring_config: 监控配置信息。
        :param pulumi.Input[builtins.str] name: 集群名称。同一个地域下，名称必须唯一。支持大小写英文字母、汉字、数字、短划线（-），长度限制为 2～64 个字符。
        :param pulumi.Input[Union['ClusterNodeStatisticsArgs', 'ClusterNodeStatisticsArgsDict']] node_statistics: 集群中各主状态下对应的节点数量统计。
        :param pulumi.Input[Union['ClusterPodsConfigArgs', 'ClusterPodsConfigArgsDict']] pods_config: Pod 的网络配置。
        :param pulumi.Input[builtins.str] project_name: 集群所属项目名称，一个集群只能归属于一个项目。只能包含英文字母、数字、下划线（_）、英文句点（.）和中划线（-）。长度限制在 64 个字符以内。默认值：default。
        :param pulumi.Input[Union['ClusterServicesConfigArgs', 'ClusterServicesConfigArgsDict']] services_config: 服务的网络配置。
        :param pulumi.Input[builtins.str] source_region: 集群源地域。
        :param pulumi.Input[Union['ClusterStatusArgs', 'ClusterStatusArgsDict']] status: 集群状态。
        :param pulumi.Input[builtins.str] type: 集群类型。
        :param pulumi.Input[builtins.str] updated_time: 集群最近一次更新的时间。标准 RFC3339 格式的 UTC+0 时间。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ClusterState.__new__(_ClusterState)

        __props__.__dict__["cluster_config"] = cluster_config
        __props__.__dict__["cluster_id"] = cluster_id
        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["delete_protection_enabled"] = delete_protection_enabled
        __props__.__dict__["description"] = description
        __props__.__dict__["kubernetes_version"] = kubernetes_version
        __props__.__dict__["kubernetes_version_create"] = kubernetes_version_create
        __props__.__dict__["logging_config"] = logging_config
        __props__.__dict__["message"] = message
        __props__.__dict__["monitoring_config"] = monitoring_config
        __props__.__dict__["name"] = name
        __props__.__dict__["node_statistics"] = node_statistics
        __props__.__dict__["pods_config"] = pods_config
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["services_config"] = services_config
        __props__.__dict__["source_region"] = source_region
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["type"] = type
        __props__.__dict__["updated_time"] = updated_time
        return Cluster(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="clusterConfig")
    def cluster_config(self) -> pulumi.Output['outputs.ClusterClusterConfig']:
        """
        集群控制面及部分节点的网络配置。
        """
        return pulumi.get(self, "cluster_config")

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Output[builtins.str]:
        """
        集群 ID。
        """
        return pulumi.get(self, "cluster_id")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        集群创建时间。标准 RFC3339 格式的 UTC+0 时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="deleteProtectionEnabled")
    def delete_protection_enabled(self) -> pulumi.Output[builtins.bool]:
        """
        集群删除保护，取值：false：（默认值）关闭删除保护。true：开启删除保护，不允许直接删除集群。
        """
        return pulumi.get(self, "delete_protection_enabled")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        集群描述。长度限制为 300 个字符以内。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="kubernetesVersion")
    def kubernetes_version(self) -> pulumi.Output[builtins.str]:
        """
        集群的 Kubernetes 版本，格式为x.xx。创建集群时，系统自动匹配该 Kubernetes 版本对应的最新 VKE 版本。（查询使用）
        """
        return pulumi.get(self, "kubernetes_version")

    @property
    @pulumi.getter(name="kubernetesVersionCreate")
    def kubernetes_version_create(self) -> pulumi.Output[builtins.str]:
        """
        集群的 Kubernetes 版本，格式为x.xx。创建集群时，系统自动匹配该 Kubernetes 版本对应的最新 VKE 版本。(创建使用)
        """
        return pulumi.get(self, "kubernetes_version_create")

    @property
    @pulumi.getter(name="loggingConfig")
    def logging_config(self) -> pulumi.Output['outputs.ClusterLoggingConfig']:
        """
        集群的日志配置信息。
        """
        return pulumi.get(self, "logging_config")

    @property
    @pulumi.getter
    def message(self) -> pulumi.Output[builtins.str]:
        """
        集群状态描述。
        """
        return pulumi.get(self, "message")

    @property
    @pulumi.getter(name="monitoringConfig")
    def monitoring_config(self) -> pulumi.Output['outputs.ClusterMonitoringConfig']:
        """
        监控配置信息。
        """
        return pulumi.get(self, "monitoring_config")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        集群名称。同一个地域下，名称必须唯一。支持大小写英文字母、汉字、数字、短划线（-），长度限制为 2～64 个字符。
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="nodeStatistics")
    def node_statistics(self) -> pulumi.Output['outputs.ClusterNodeStatistics']:
        """
        集群中各主状态下对应的节点数量统计。
        """
        return pulumi.get(self, "node_statistics")

    @property
    @pulumi.getter(name="podsConfig")
    def pods_config(self) -> pulumi.Output['outputs.ClusterPodsConfig']:
        """
        Pod 的网络配置。
        """
        return pulumi.get(self, "pods_config")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        集群所属项目名称，一个集群只能归属于一个项目。只能包含英文字母、数字、下划线（_）、英文句点（.）和中划线（-）。长度限制在 64 个字符以内。默认值：default。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="servicesConfig")
    def services_config(self) -> pulumi.Output['outputs.ClusterServicesConfig']:
        """
        服务的网络配置。
        """
        return pulumi.get(self, "services_config")

    @property
    @pulumi.getter(name="sourceRegion")
    def source_region(self) -> pulumi.Output[builtins.str]:
        """
        集群源地域。
        """
        return pulumi.get(self, "source_region")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output['outputs.ClusterStatus']:
        """
        集群状态。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.ClusterTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[builtins.str]:
        """
        集群类型。
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> pulumi.Output[builtins.str]:
        """
        集群最近一次更新的时间。标准 RFC3339 格式的 UTC+0 时间。
        """
        return pulumi.get(self, "updated_time")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['GatewayArgs', 'Gateway']

@pulumi.input_type
class GatewayArgs:
    def __init__(__self__, *,
                 name: pulumi.Input[builtins.str],
                 comments: Optional[pulumi.Input[builtins.str]] = None,
                 custom_log: Optional[pulumi.Input['GatewayCustomLogArgs']] = None,
                 log_spec: Optional[pulumi.Input['GatewayLogSpecArgs']] = None,
                 monitor_spec: Optional[pulumi.Input['GatewayMonitorSpecArgs']] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 resource_spec: Optional[pulumi.Input['GatewayResourceSpecArgs']] = None,
                 subnet_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 trace_spec: Optional[pulumi.Input['GatewayTraceSpecArgs']] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a Gateway resource.
        :param pulumi.Input[builtins.str] name: 网关名称。
        :param pulumi.Input[builtins.str] comments: 网关备注信息。长度限制为0~253个字符。
        :param pulumi.Input['GatewayCustomLogArgs'] custom_log: 自定义日志配置。
        :param pulumi.Input['GatewayLogSpecArgs'] log_spec: 日志配置。
        :param pulumi.Input['GatewayMonitorSpecArgs'] monitor_spec: 监控配置信息。
        :param pulumi.Input[builtins.str] project_name: 项目名称。
        :param pulumi.Input['GatewayResourceSpecArgs'] resource_spec: 资源规格配置信息。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] subnet_ids: 子网ID列表。长度限制为1~2个。
        :param pulumi.Input['GatewayTraceSpecArgs'] trace_spec: 链路追踪配置信息。
        :param pulumi.Input[builtins.str] type: 网关类型，取值：standard：标准网关。serverless：Serverless网关（暂不支持）。
        :param pulumi.Input[builtins.str] vpc_id: VPC ID。
        """
        pulumi.set(__self__, "name", name)
        if comments is not None:
            pulumi.set(__self__, "comments", comments)
        if custom_log is not None:
            pulumi.set(__self__, "custom_log", custom_log)
        if log_spec is not None:
            pulumi.set(__self__, "log_spec", log_spec)
        if monitor_spec is not None:
            pulumi.set(__self__, "monitor_spec", monitor_spec)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if resource_spec is not None:
            pulumi.set(__self__, "resource_spec", resource_spec)
        if subnet_ids is not None:
            pulumi.set(__self__, "subnet_ids", subnet_ids)
        if trace_spec is not None:
            pulumi.set(__self__, "trace_spec", trace_spec)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[builtins.str]:
        """
        网关名称。
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def comments(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网关备注信息。长度限制为0~253个字符。
        """
        return pulumi.get(self, "comments")

    @comments.setter
    def comments(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "comments", value)

    @property
    @pulumi.getter(name="customLog")
    def custom_log(self) -> Optional[pulumi.Input['GatewayCustomLogArgs']]:
        """
        自定义日志配置。
        """
        return pulumi.get(self, "custom_log")

    @custom_log.setter
    def custom_log(self, value: Optional[pulumi.Input['GatewayCustomLogArgs']]):
        pulumi.set(self, "custom_log", value)

    @property
    @pulumi.getter(name="logSpec")
    def log_spec(self) -> Optional[pulumi.Input['GatewayLogSpecArgs']]:
        """
        日志配置。
        """
        return pulumi.get(self, "log_spec")

    @log_spec.setter
    def log_spec(self, value: Optional[pulumi.Input['GatewayLogSpecArgs']]):
        pulumi.set(self, "log_spec", value)

    @property
    @pulumi.getter(name="monitorSpec")
    def monitor_spec(self) -> Optional[pulumi.Input['GatewayMonitorSpecArgs']]:
        """
        监控配置信息。
        """
        return pulumi.get(self, "monitor_spec")

    @monitor_spec.setter
    def monitor_spec(self, value: Optional[pulumi.Input['GatewayMonitorSpecArgs']]):
        pulumi.set(self, "monitor_spec", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        项目名称。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="resourceSpec")
    def resource_spec(self) -> Optional[pulumi.Input['GatewayResourceSpecArgs']]:
        """
        资源规格配置信息。
        """
        return pulumi.get(self, "resource_spec")

    @resource_spec.setter
    def resource_spec(self, value: Optional[pulumi.Input['GatewayResourceSpecArgs']]):
        pulumi.set(self, "resource_spec", value)

    @property
    @pulumi.getter(name="subnetIds")
    def subnet_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        子网ID列表。长度限制为1~2个。
        """
        return pulumi.get(self, "subnet_ids")

    @subnet_ids.setter
    def subnet_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "subnet_ids", value)

    @property
    @pulumi.getter(name="traceSpec")
    def trace_spec(self) -> Optional[pulumi.Input['GatewayTraceSpecArgs']]:
        """
        链路追踪配置信息。
        """
        return pulumi.get(self, "trace_spec")

    @trace_spec.setter
    def trace_spec(self, value: Optional[pulumi.Input['GatewayTraceSpecArgs']]):
        pulumi.set(self, "trace_spec", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网关类型，取值：standard：标准网关。serverless：Serverless网关（暂不支持）。
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPC ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpc_id", value)


@pulumi.input_type
class _GatewayState:
    def __init__(__self__, *,
                 backend_spec: Optional[pulumi.Input['GatewayBackendSpecArgs']] = None,
                 comments: Optional[pulumi.Input[builtins.str]] = None,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 custom_log: Optional[pulumi.Input['GatewayCustomLogArgs']] = None,
                 events: Optional[pulumi.Input[Sequence[pulumi.Input['GatewayEventArgs']]]] = None,
                 gateway_id: Optional[pulumi.Input[builtins.str]] = None,
                 log_spec: Optional[pulumi.Input['GatewayLogSpecArgs']] = None,
                 message: Optional[pulumi.Input[builtins.str]] = None,
                 monitor_spec: Optional[pulumi.Input['GatewayMonitorSpecArgs']] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 network_spec: Optional[pulumi.Input['GatewayNetworkSpecArgs']] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 resource_spec: Optional[pulumi.Input['GatewayResourceSpecArgs']] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 subnet_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 trace_spec: Optional[pulumi.Input['GatewayTraceSpecArgs']] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 version: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Gateway resources.
        :param pulumi.Input['GatewayBackendSpecArgs'] backend_spec: 后端服务配置信息。
        :param pulumi.Input[builtins.str] comments: 网关备注信息。长度限制为0~253个字符。
        :param pulumi.Input[builtins.str] created_time: 网关创建时间。
        :param pulumi.Input['GatewayCustomLogArgs'] custom_log: 自定义日志配置。
        :param pulumi.Input[builtins.str] gateway_id: 网关实例ID。
        :param pulumi.Input['GatewayLogSpecArgs'] log_spec: 日志配置。
        :param pulumi.Input[builtins.str] message: 网关创建失败、删除失败或异常时的错误信息。
        :param pulumi.Input['GatewayMonitorSpecArgs'] monitor_spec: 监控配置信息。
        :param pulumi.Input[builtins.str] name: 网关名称。
        :param pulumi.Input['GatewayNetworkSpecArgs'] network_spec: 网络配置信息。
        :param pulumi.Input[builtins.str] project_name: 项目名称。
        :param pulumi.Input['GatewayResourceSpecArgs'] resource_spec: 资源规格配置信息。
        :param pulumi.Input[builtins.str] status: 网关状态，取值：Creating：创建中。CreatedFailed：创建失败。Updating：更新中。Running：运行中。Deleting：删除中。DeletedFailed：删除失败。Abnormal：异常。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] subnet_ids: 子网ID列表。长度限制为1~2个。
        :param pulumi.Input['GatewayTraceSpecArgs'] trace_spec: 链路追踪配置信息。
        :param pulumi.Input[builtins.str] type: 网关类型，取值：standard：标准网关。serverless：Serverless网关（暂不支持）。
        :param pulumi.Input[builtins.str] version: 网关版本。
        :param pulumi.Input[builtins.str] vpc_id: VPC ID。
        """
        if backend_spec is not None:
            pulumi.set(__self__, "backend_spec", backend_spec)
        if comments is not None:
            pulumi.set(__self__, "comments", comments)
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if custom_log is not None:
            pulumi.set(__self__, "custom_log", custom_log)
        if events is not None:
            pulumi.set(__self__, "events", events)
        if gateway_id is not None:
            pulumi.set(__self__, "gateway_id", gateway_id)
        if log_spec is not None:
            pulumi.set(__self__, "log_spec", log_spec)
        if message is not None:
            pulumi.set(__self__, "message", message)
        if monitor_spec is not None:
            pulumi.set(__self__, "monitor_spec", monitor_spec)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if network_spec is not None:
            pulumi.set(__self__, "network_spec", network_spec)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if resource_spec is not None:
            pulumi.set(__self__, "resource_spec", resource_spec)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if subnet_ids is not None:
            pulumi.set(__self__, "subnet_ids", subnet_ids)
        if trace_spec is not None:
            pulumi.set(__self__, "trace_spec", trace_spec)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if version is not None:
            pulumi.set(__self__, "version", version)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)

    @property
    @pulumi.getter(name="backendSpec")
    def backend_spec(self) -> Optional[pulumi.Input['GatewayBackendSpecArgs']]:
        """
        后端服务配置信息。
        """
        return pulumi.get(self, "backend_spec")

    @backend_spec.setter
    def backend_spec(self, value: Optional[pulumi.Input['GatewayBackendSpecArgs']]):
        pulumi.set(self, "backend_spec", value)

    @property
    @pulumi.getter
    def comments(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网关备注信息。长度限制为0~253个字符。
        """
        return pulumi.get(self, "comments")

    @comments.setter
    def comments(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "comments", value)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网关创建时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter(name="customLog")
    def custom_log(self) -> Optional[pulumi.Input['GatewayCustomLogArgs']]:
        """
        自定义日志配置。
        """
        return pulumi.get(self, "custom_log")

    @custom_log.setter
    def custom_log(self, value: Optional[pulumi.Input['GatewayCustomLogArgs']]):
        pulumi.set(self, "custom_log", value)

    @property
    @pulumi.getter
    def events(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['GatewayEventArgs']]]]:
        return pulumi.get(self, "events")

    @events.setter
    def events(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['GatewayEventArgs']]]]):
        pulumi.set(self, "events", value)

    @property
    @pulumi.getter(name="gatewayId")
    def gateway_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网关实例ID。
        """
        return pulumi.get(self, "gateway_id")

    @gateway_id.setter
    def gateway_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "gateway_id", value)

    @property
    @pulumi.getter(name="logSpec")
    def log_spec(self) -> Optional[pulumi.Input['GatewayLogSpecArgs']]:
        """
        日志配置。
        """
        return pulumi.get(self, "log_spec")

    @log_spec.setter
    def log_spec(self, value: Optional[pulumi.Input['GatewayLogSpecArgs']]):
        pulumi.set(self, "log_spec", value)

    @property
    @pulumi.getter
    def message(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网关创建失败、删除失败或异常时的错误信息。
        """
        return pulumi.get(self, "message")

    @message.setter
    def message(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "message", value)

    @property
    @pulumi.getter(name="monitorSpec")
    def monitor_spec(self) -> Optional[pulumi.Input['GatewayMonitorSpecArgs']]:
        """
        监控配置信息。
        """
        return pulumi.get(self, "monitor_spec")

    @monitor_spec.setter
    def monitor_spec(self, value: Optional[pulumi.Input['GatewayMonitorSpecArgs']]):
        pulumi.set(self, "monitor_spec", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网关名称。
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="networkSpec")
    def network_spec(self) -> Optional[pulumi.Input['GatewayNetworkSpecArgs']]:
        """
        网络配置信息。
        """
        return pulumi.get(self, "network_spec")

    @network_spec.setter
    def network_spec(self, value: Optional[pulumi.Input['GatewayNetworkSpecArgs']]):
        pulumi.set(self, "network_spec", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        项目名称。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="resourceSpec")
    def resource_spec(self) -> Optional[pulumi.Input['GatewayResourceSpecArgs']]:
        """
        资源规格配置信息。
        """
        return pulumi.get(self, "resource_spec")

    @resource_spec.setter
    def resource_spec(self, value: Optional[pulumi.Input['GatewayResourceSpecArgs']]):
        pulumi.set(self, "resource_spec", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网关状态，取值：Creating：创建中。CreatedFailed：创建失败。Updating：更新中。Running：运行中。Deleting：删除中。DeletedFailed：删除失败。Abnormal：异常。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="subnetIds")
    def subnet_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        子网ID列表。长度限制为1~2个。
        """
        return pulumi.get(self, "subnet_ids")

    @subnet_ids.setter
    def subnet_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "subnet_ids", value)

    @property
    @pulumi.getter(name="traceSpec")
    def trace_spec(self) -> Optional[pulumi.Input['GatewayTraceSpecArgs']]:
        """
        链路追踪配置信息。
        """
        return pulumi.get(self, "trace_spec")

    @trace_spec.setter
    def trace_spec(self, value: Optional[pulumi.Input['GatewayTraceSpecArgs']]):
        pulumi.set(self, "trace_spec", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网关类型，取值：standard：标准网关。serverless：Serverless网关（暂不支持）。
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter
    def version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网关版本。
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "version", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPC ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpc_id", value)


@pulumi.type_token("bytepluscc:apig/gateway:Gateway")
class Gateway(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 comments: Optional[pulumi.Input[builtins.str]] = None,
                 custom_log: Optional[pulumi.Input[Union['GatewayCustomLogArgs', 'GatewayCustomLogArgsDict']]] = None,
                 log_spec: Optional[pulumi.Input[Union['GatewayLogSpecArgs', 'GatewayLogSpecArgsDict']]] = None,
                 monitor_spec: Optional[pulumi.Input[Union['GatewayMonitorSpecArgs', 'GatewayMonitorSpecArgsDict']]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 resource_spec: Optional[pulumi.Input[Union['GatewayResourceSpecArgs', 'GatewayResourceSpecArgsDict']]] = None,
                 subnet_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 trace_spec: Optional[pulumi.Input[Union['GatewayTraceSpecArgs', 'GatewayTraceSpecArgsDict']]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        API网关(Gateway)是API管理服务的核心组件，负责接收、处理、转发API请求，并提供安全认证、流量控制等功能。

        ## Import

        ```sh
        $ pulumi import bytepluscc:apig/gateway:Gateway example "gateway_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] comments: 网关备注信息。长度限制为0~253个字符。
        :param pulumi.Input[Union['GatewayCustomLogArgs', 'GatewayCustomLogArgsDict']] custom_log: 自定义日志配置。
        :param pulumi.Input[Union['GatewayLogSpecArgs', 'GatewayLogSpecArgsDict']] log_spec: 日志配置。
        :param pulumi.Input[Union['GatewayMonitorSpecArgs', 'GatewayMonitorSpecArgsDict']] monitor_spec: 监控配置信息。
        :param pulumi.Input[builtins.str] name: 网关名称。
        :param pulumi.Input[builtins.str] project_name: 项目名称。
        :param pulumi.Input[Union['GatewayResourceSpecArgs', 'GatewayResourceSpecArgsDict']] resource_spec: 资源规格配置信息。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] subnet_ids: 子网ID列表。长度限制为1~2个。
        :param pulumi.Input[Union['GatewayTraceSpecArgs', 'GatewayTraceSpecArgsDict']] trace_spec: 链路追踪配置信息。
        :param pulumi.Input[builtins.str] type: 网关类型，取值：standard：标准网关。serverless：Serverless网关（暂不支持）。
        :param pulumi.Input[builtins.str] vpc_id: VPC ID。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GatewayArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        API网关(Gateway)是API管理服务的核心组件，负责接收、处理、转发API请求，并提供安全认证、流量控制等功能。

        ## Import

        ```sh
        $ pulumi import bytepluscc:apig/gateway:Gateway example "gateway_id"
        ```

        :param str resource_name: The name of the resource.
        :param GatewayArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GatewayArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 comments: Optional[pulumi.Input[builtins.str]] = None,
                 custom_log: Optional[pulumi.Input[Union['GatewayCustomLogArgs', 'GatewayCustomLogArgsDict']]] = None,
                 log_spec: Optional[pulumi.Input[Union['GatewayLogSpecArgs', 'GatewayLogSpecArgsDict']]] = None,
                 monitor_spec: Optional[pulumi.Input[Union['GatewayMonitorSpecArgs', 'GatewayMonitorSpecArgsDict']]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 resource_spec: Optional[pulumi.Input[Union['GatewayResourceSpecArgs', 'GatewayResourceSpecArgsDict']]] = None,
                 subnet_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 trace_spec: Optional[pulumi.Input[Union['GatewayTraceSpecArgs', 'GatewayTraceSpecArgsDict']]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GatewayArgs.__new__(GatewayArgs)

            __props__.__dict__["comments"] = comments
            __props__.__dict__["custom_log"] = custom_log
            __props__.__dict__["log_spec"] = log_spec
            __props__.__dict__["monitor_spec"] = monitor_spec
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
            __props__.__dict__["project_name"] = project_name
            __props__.__dict__["resource_spec"] = resource_spec
            __props__.__dict__["subnet_ids"] = subnet_ids
            __props__.__dict__["trace_spec"] = trace_spec
            __props__.__dict__["type"] = type
            __props__.__dict__["vpc_id"] = vpc_id
            __props__.__dict__["backend_spec"] = None
            __props__.__dict__["created_time"] = None
            __props__.__dict__["events"] = None
            __props__.__dict__["gateway_id"] = None
            __props__.__dict__["message"] = None
            __props__.__dict__["network_spec"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["version"] = None
        super(Gateway, __self__).__init__(
            'bytepluscc:apig/gateway:Gateway',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            backend_spec: Optional[pulumi.Input[Union['GatewayBackendSpecArgs', 'GatewayBackendSpecArgsDict']]] = None,
            comments: Optional[pulumi.Input[builtins.str]] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            custom_log: Optional[pulumi.Input[Union['GatewayCustomLogArgs', 'GatewayCustomLogArgsDict']]] = None,
            events: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GatewayEventArgs', 'GatewayEventArgsDict']]]]] = None,
            gateway_id: Optional[pulumi.Input[builtins.str]] = None,
            log_spec: Optional[pulumi.Input[Union['GatewayLogSpecArgs', 'GatewayLogSpecArgsDict']]] = None,
            message: Optional[pulumi.Input[builtins.str]] = None,
            monitor_spec: Optional[pulumi.Input[Union['GatewayMonitorSpecArgs', 'GatewayMonitorSpecArgsDict']]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            network_spec: Optional[pulumi.Input[Union['GatewayNetworkSpecArgs', 'GatewayNetworkSpecArgsDict']]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            resource_spec: Optional[pulumi.Input[Union['GatewayResourceSpecArgs', 'GatewayResourceSpecArgsDict']]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            subnet_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            trace_spec: Optional[pulumi.Input[Union['GatewayTraceSpecArgs', 'GatewayTraceSpecArgsDict']]] = None,
            type: Optional[pulumi.Input[builtins.str]] = None,
            version: Optional[pulumi.Input[builtins.str]] = None,
            vpc_id: Optional[pulumi.Input[builtins.str]] = None) -> 'Gateway':
        """
        Get an existing Gateway resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['GatewayBackendSpecArgs', 'GatewayBackendSpecArgsDict']] backend_spec: 后端服务配置信息。
        :param pulumi.Input[builtins.str] comments: 网关备注信息。长度限制为0~253个字符。
        :param pulumi.Input[builtins.str] created_time: 网关创建时间。
        :param pulumi.Input[Union['GatewayCustomLogArgs', 'GatewayCustomLogArgsDict']] custom_log: 自定义日志配置。
        :param pulumi.Input[builtins.str] gateway_id: 网关实例ID。
        :param pulumi.Input[Union['GatewayLogSpecArgs', 'GatewayLogSpecArgsDict']] log_spec: 日志配置。
        :param pulumi.Input[builtins.str] message: 网关创建失败、删除失败或异常时的错误信息。
        :param pulumi.Input[Union['GatewayMonitorSpecArgs', 'GatewayMonitorSpecArgsDict']] monitor_spec: 监控配置信息。
        :param pulumi.Input[builtins.str] name: 网关名称。
        :param pulumi.Input[Union['GatewayNetworkSpecArgs', 'GatewayNetworkSpecArgsDict']] network_spec: 网络配置信息。
        :param pulumi.Input[builtins.str] project_name: 项目名称。
        :param pulumi.Input[Union['GatewayResourceSpecArgs', 'GatewayResourceSpecArgsDict']] resource_spec: 资源规格配置信息。
        :param pulumi.Input[builtins.str] status: 网关状态，取值：Creating：创建中。CreatedFailed：创建失败。Updating：更新中。Running：运行中。Deleting：删除中。DeletedFailed：删除失败。Abnormal：异常。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] subnet_ids: 子网ID列表。长度限制为1~2个。
        :param pulumi.Input[Union['GatewayTraceSpecArgs', 'GatewayTraceSpecArgsDict']] trace_spec: 链路追踪配置信息。
        :param pulumi.Input[builtins.str] type: 网关类型，取值：standard：标准网关。serverless：Serverless网关（暂不支持）。
        :param pulumi.Input[builtins.str] version: 网关版本。
        :param pulumi.Input[builtins.str] vpc_id: VPC ID。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GatewayState.__new__(_GatewayState)

        __props__.__dict__["backend_spec"] = backend_spec
        __props__.__dict__["comments"] = comments
        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["custom_log"] = custom_log
        __props__.__dict__["events"] = events
        __props__.__dict__["gateway_id"] = gateway_id
        __props__.__dict__["log_spec"] = log_spec
        __props__.__dict__["message"] = message
        __props__.__dict__["monitor_spec"] = monitor_spec
        __props__.__dict__["name"] = name
        __props__.__dict__["network_spec"] = network_spec
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["resource_spec"] = resource_spec
        __props__.__dict__["status"] = status
        __props__.__dict__["subnet_ids"] = subnet_ids
        __props__.__dict__["trace_spec"] = trace_spec
        __props__.__dict__["type"] = type
        __props__.__dict__["version"] = version
        __props__.__dict__["vpc_id"] = vpc_id
        return Gateway(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="backendSpec")
    def backend_spec(self) -> pulumi.Output['outputs.GatewayBackendSpec']:
        """
        后端服务配置信息。
        """
        return pulumi.get(self, "backend_spec")

    @property
    @pulumi.getter
    def comments(self) -> pulumi.Output[builtins.str]:
        """
        网关备注信息。长度限制为0~253个字符。
        """
        return pulumi.get(self, "comments")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        网关创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="customLog")
    def custom_log(self) -> pulumi.Output['outputs.GatewayCustomLog']:
        """
        自定义日志配置。
        """
        return pulumi.get(self, "custom_log")

    @property
    @pulumi.getter
    def events(self) -> pulumi.Output[Sequence['outputs.GatewayEvent']]:
        return pulumi.get(self, "events")

    @property
    @pulumi.getter(name="gatewayId")
    def gateway_id(self) -> pulumi.Output[builtins.str]:
        """
        网关实例ID。
        """
        return pulumi.get(self, "gateway_id")

    @property
    @pulumi.getter(name="logSpec")
    def log_spec(self) -> pulumi.Output['outputs.GatewayLogSpec']:
        """
        日志配置。
        """
        return pulumi.get(self, "log_spec")

    @property
    @pulumi.getter
    def message(self) -> pulumi.Output[builtins.str]:
        """
        网关创建失败、删除失败或异常时的错误信息。
        """
        return pulumi.get(self, "message")

    @property
    @pulumi.getter(name="monitorSpec")
    def monitor_spec(self) -> pulumi.Output['outputs.GatewayMonitorSpec']:
        """
        监控配置信息。
        """
        return pulumi.get(self, "monitor_spec")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        网关名称。
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="networkSpec")
    def network_spec(self) -> pulumi.Output['outputs.GatewayNetworkSpec']:
        """
        网络配置信息。
        """
        return pulumi.get(self, "network_spec")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        项目名称。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="resourceSpec")
    def resource_spec(self) -> pulumi.Output['outputs.GatewayResourceSpec']:
        """
        资源规格配置信息。
        """
        return pulumi.get(self, "resource_spec")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        网关状态，取值：Creating：创建中。CreatedFailed：创建失败。Updating：更新中。Running：运行中。Deleting：删除中。DeletedFailed：删除失败。Abnormal：异常。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="subnetIds")
    def subnet_ids(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        子网ID列表。长度限制为1~2个。
        """
        return pulumi.get(self, "subnet_ids")

    @property
    @pulumi.getter(name="traceSpec")
    def trace_spec(self) -> pulumi.Output['outputs.GatewayTraceSpec']:
        """
        链路追踪配置信息。
        """
        return pulumi.get(self, "trace_spec")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[builtins.str]:
        """
        网关类型，取值：standard：标准网关。serverless：Serverless网关（暂不支持）。
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def version(self) -> pulumi.Output[builtins.str]:
        """
        网关版本。
        """
        return pulumi.get(self, "version")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Output[builtins.str]:
        """
        VPC ID。
        """
        return pulumi.get(self, "vpc_id")

